import{d as u,an as l,z as c,n as p,c as a,g as m,f as i,w as d,e as v,q as g,i as f}from"./index-e34071c2.js";import{T as h}from"./Toolbar-bbf3d11a.js";import{V as _}from"./VList-5a526902.js";import"./VListItem-6fb16d04.js";import"./VMenu-8ea0aa0a.js";import"./VToolbar-790d92bd.js";import"./_plugin-vue_export-helper-c27b6911.js";const y=f("div",{style:{height:"15px"}},null,-1),V=u({__name:"Settings",setup(b){const r=l(),t=c(()=>{var e,o,n;return(e=r.currentRoute.value.name)!=null&&e.toString().includes("player")?"players":(o=r.currentRoute.value.name)!=null&&o.toString().includes("core")?"core":(n=r.currentRoute.value.name)!=null&&n.toString().includes("frontend")?"frontend":"providers"});return(e,o)=>{const n=p("router-view");return a(),m("div",null,[i(h,{icon:"mdi-cog-outline",title:e.$t("settings.settings"),"show-loading":!0,"menu-items":[{label:"settings.providers",icon:"mdi-apps",action:()=>{e.$router.push({name:"providersettings"})},active:t.value=="providers"},{label:"settings.players",icon:"mdi-speaker-multiple",action:()=>{e.$router.push({name:"playersettings"})},active:t.value=="players"},{label:"settings.core",icon:"mdi-engine",action:()=>{e.$router.push({name:"coresettings"})},active:t.value=="core"},{label:"settings.frontend",icon:"mdi-palette-advanced",action:()=>{e.$router.push({name:"frontendsettings"})},active:t.value=="frontend"}]},null,8,["title","menu-items"]),i(_),y,i(n,{app:""},{default:d(({Component:s})=>[(a(),v(g(s)))]),_:1})])}}});export{V as default};
