import{z as n,c as l,e as p,Z as u,h as v,w as d,a1 as f,G as _}from"./index-e34071c2.js";import{_ as m}from"./_plugin-vue_export-helper-c27b6911.js";import{s as b}from"./VListItem-6fb16d04.js";const h={props:{variant:{type:String,default:"default",validator:e=>["plain","default","responsive","icon","list"].includes(e)}},setup(e,r){const t={},s=n(()=>({...t,class:"v-btn--variant-responsive",ripple:!0,icon:!0,style:"height: min(calc(100vw - 40px), calc(100vh - 340px)); width: min(calc(100vw - 40px), calc(100vh - 340px));"})),o=n(()=>({...t,ripple:!1})),c=n(()=>({...t,density:"comfortable"}));return{btnProps:n(()=>{switch(e.variant){case"default":return t;case"plain":return t;case"responsive":return s.value;case"icon":return o.value;case"list":return c.value;default:return t}})}}};function w(e,r,t,s,o,c){return l(),p(b,_(s.btnProps,{variant:"plain"}),u({_:2},[v(e.$slots,(i,a)=>({name:a,fn:d(()=>[f(e.$slots,a)])}))]),1040)}const $=m(h,[["render",w]]);export{$ as B};
