.col-2[data-v-27d7dcf5]{width:50%;max-width:50%;flex-basis:50%;padding:8px}.col-3[data-v-27d7dcf5]{width:33.3%;max-width:33.3%;flex-basis:33.3%;padding:8px}.col-4[data-v-27d7dcf5]{width:25%;max-width:25%;flex-basis:25%;padding:8px}.col-5[data-v-27d7dcf5]{width:20%;max-width:20%;flex-basis:20%;padding:8px}.col-6[data-v-27d7dcf5]{width:16.6%;max-width:16.6%;flex-basis:16.6%;padding:8px}.col-7[data-v-27d7dcf5]{width:14.2%;max-width:14.2%;flex-basis:14.2%;padding:8px}.col-8[data-v-27d7dcf5]{width:12.5%;max-width:12.5%;flex-basis:12.5%;padding:8px}.col-9[data-v-27d7dcf5]{width:11.1%;max-width:11.1%;flex-basis:11.1%;padding:8px}.v-list-item--density-compact[data-v-27d7dcf5]{padding:5px!important}panel-item-details[data-v-27d7dcf5] .v-list-item__content{height:30px}
