import{d as s,a5 as m,z as n,X as e,c as l,g as c,f as u,b as f}from"./index-e34071c2.js";import{I as h}from"./ItemsListing-e7c9377b.js";import"./VCheckbox-081529bb.js";import"./eventbus-edb4a70e.js";import"./VListItem-6fb16d04.js";import"./VCheckboxBtn-43c6a5b9.js";import"./VList-5a526902.js";import"./VCardText-2a290ffe.js";import"./VCard-0f63f60c.js";import"./VMenu-8ea0aa0a.js";import"./_plugin-vue_export-helper-c27b6911.js";import"./ListItem-f09faddc.js";import"./Button-d52131a6.js";import"./VSpacer-b7ae4876.js";/* empty css              */import"./PanelviewItemCompact-8de8744a.js";import"./VAlert-cd8a958f.js";import"./Container-1af89f37.js";import"./Toolbar-bbf3d11a.js";import"./VToolbar-790d92bd.js";import"./VTextField-df721147.js";import"./VInfiniteScroll-311fcdfe.js";import"./layout-4fa46c33.js";import"./VVirtualScroll-8b839030.js";const J=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:o}=m(),a=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),p=async function(r){return await f.browse(t.path)};return(r,w)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":p,"sort-keys":["original","name","name_desc"],title:a.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{J as default};
