.header.v-toolbar[data-v-00198094]{height:55px;font-family:JetBrains Mono Medium}.widget-row[data-v-00198094]{margin-bottom:20px;margin-left:0;padding-left:0}.widget-row-panel-item[data-v-00198094]{margin-bottom:10px}.v-slide-group__prev[data-v-00198094]{min-width:0px!important}.v-slide-group__prev.v-slide-group__prev--disabled[data-v-00198094]{visibility:hidden;margin-right:-15px}.v-slide-group__next[data-v-00198094]{min-width:15px!important}.v-slide-group__next.v-slide-group__next--disabled[data-v-00198094]{visibility:hidden}.v-card[data-v-ca997964]{transition:opacity .4s ease-in-out;padding:0}.panel-item[data-v-ca997964]{height:75px;margin-right:25px;border:none;border-style:none!important;padding:10px}.panel-item-idle[data-v-ca997964]{opacity:.5}.panel-item-details[data-v-ca997964]{align-items:center;margin-left:0!important;padding-left:0!important;padding-right:0!important}.header.v-toolbar[data-v-7d6eddfa]{height:55px;font-family:JetBrains Mono Medium}.home-card[data-v-7d6eddfa]{min-width:80px;text-align:center;padding-top:12px;padding-bottom:8px}.widget-row[data-v-7d6eddfa]{margin-bottom:20px;margin-left:0;padding-left:0}.widget-row-panel-item[data-v-7d6eddfa]{margin-bottom:10px}.v-slide-group__prev[data-v-7d6eddfa]{min-width:0px!important}.v-slide-group__prev.v-slide-group__prev--disabled[data-v-7d6eddfa]{visibility:hidden;margin-right:-15px}.v-slide-group__next[data-v-7d6eddfa]{min-width:15px!important}.v-slide-group__next.v-slide-group__next--disabled[data-v-7d6eddfa]{visibility:hidden}.v-progress-circular[data-v-6e8c4c0d]{display:block;margin-inline:auto}
