import{z as r,a8 as i,l as c,m as u,J as d,f as p,c as f,e as m,Z as v,h as _,G as C,w as y,a1 as P}from"./index-e34071c2.js";import{_ as k}from"./_plugin-vue_export-helper-c27b6911.js";/* empty css              */import{m as g,a as V,b,u as h,c as w}from"./VListItem-6fb16d04.js";const $={props:{variant:{type:String,default:"default",validator:e=>["default","panel"].includes(e)}},setup(e,n){const a=r(()=>({class:"container-default"})),t=r(()=>({class:i.theme.current.value.dark?"container-default container-panels-dark":"container-default container-panels-light"}));return{btnProps:r(()=>{switch(e.variant){case"default":return a.value;case"panel":return t.value;default:return a.value}})}}};const x=c({fluid:{type:Boolean,default:!1},...g(),...V(),...b()},"VContainer"),S=u()({name:"VContainer",props:x(),setup(e,n){let{slots:a}=n;const{rtlClasses:t}=d(),{dimensionStyles:s}=h(e);return w(()=>p(e.tag,{class:["v-container",{"v-container--fluid":e.fluid},t.value,e.class],style:[s.value,e.style]},a)),{}}});function B(e,n,a,t,s,l){return f(),m(S,C(t.btnProps,{variant:"default",fluid:""}),v({_:2},[_(e.$slots,(D,o)=>({name:o,fn:y(()=>[P(e.$slots,o,{},void 0,!0)])}))]),1040)}const I=k($,[["render",B],["__scopeId","data-v-7629334b"]]);export{I as C};
